## ---------------------------------------------
##
## Script name: table-a2.R
##
## Purpose of script: Generate Results for
##                    Appendix Table A-2
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
##
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(tidyverse)
library(stargazer)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Summary statistics ------------------------------------------------------

# Define and select variables
sum_vars <- c(
  "apRent_chg08", "apPurc_chg08", "houPurc_chg08",
  "lvng_area_pc", "resbuild_pc", "bigapts_pc", "houses_pc", "smallapts_pc",
  "permits_apts_pc", "new_apts_pc", "new_hou_pc", "land_prc", "developable",
  "emp_wz_ind_pt", "hiring_r", "tight", "unemp_r", "vac_r", "svb_hq_pt",
  "gdp_pc", "house_inc", "guest_nights",
  "hh_size", "age", "births_pc", "deaths_pc", "divorces", "fem_pc", 
  "mig", "students_pc",
  "comm_net", "dom_mig_pc", "ext_mig_pc", "pop_dens", "total_mig_pc",
  "hazard_rate", "sb_lend", "debtor_ratio", "neg_credscore",
  "prop_tax_factor", "rent_control", "new_res_area", "housing_vac"
)

panel_krs_sum <- panel_krs %>%
  ungroup() %>%
  select(all_of(sum_vars)) %>%
  as.data.frame()

# Export as Summary Table
stargazer(panel_krs_sum,
  type = "html", iqr = T,
  covariate.labels = c(
    "Apartment rents", "Apartment purchase prices",
    "House purchase prices",
    "Living area pc", "Residential buildings pc", "Share of big apartments", 
    "Share of family houses", "Share of small apartments",
    "Building permits pc", "Completed apartments pc", "Completed houses pc", 
    "Land prices", "Share of developable land",
    "Emp. share in manufacturing", "Hiring rate", "Labor market tightness",
    "Unemployment rate", "Vacancy rate", "Share of academics",
    "GDP pc", "Household income pc", "Overnight stays",
    "Average household size", "Average population age", "Birth rate", 
    "Death rate", "Divorce rate", "Female share", "Migrant share", 
    "Student ratio",
    "Commuter balance", "Domestic migration balance", 
    "External migration balance", "Population density",
    "Total migration balance",
    "Hazard rate", "Mortgage lending", "Private debtor rate", 
    "Share of subprime", "Property taxe rate", "Rent control",
    "Residential zoning","Housing vacancy"
  ),
  out = "../tables/table-a2.html"
)
