## ---------------------------------------------
##
## Script name: table-b1.R
##
## Purpose of script: Generate Results for
##                    Appendix Table B-1
##
## Paper: Regional Supply and Demand Fundamentals
##        in the German Housing Price Boom
#
## Authors: Lars Brausewetter, Stephan Thomsen,
##          Johannes Trunzer
##
## Institution: Leibniz University Hannover
##
## Date: November 26, 2023
##
## ---------------------------------------------



# Intro -------------------------------------------------------------------

# Load packages
library(openxlsx)
library(tidyverse)

# Clear environment
rm(list = ls())



# Import ------------------------------------------------------------------

# Data
panel_krs <- readRDS("../data/panel_krs.RDS")



# Summary statistics ------------------------------------------------------

## Table B-1 ##

# Panel A: Apartment Rents
apRent_sum <- panel_krs %>%
  select(apRent_chg08, year) %>%
  group_by(year) %>%
  summarise(
    q10 = quantile(apRent_chg08, 0.1, na.rm = T),
    q25 = quantile(apRent_chg08, 0.25, na.rm = T),
    med = median(apRent_chg08, na.rm = T),
    q75 = quantile(apRent_chg08, 0.75, na.rm = T),
    q90 = quantile(apRent_chg08, 0.9, na.rm = T),
    mean = mean(apRent_chg08, na.rm = T),
    sd = sd(apRent_chg08, na.rm = T)
  )
apRent_sum[2:ncol(apRent_sum)] <- apply(
  apRent_sum[2:ncol(apRent_sum)],
  2, function(x) round(x, digits = 2)
)
write.xlsx(apRent_sum, "../tables/table-b1_1.xlsx")

# Panel B: Apartment purchase prices
apPurc_sum <- panel_krs %>%
  select(apPurc_chg08, year) %>%
  group_by(year) %>%
  summarise(
    q10 = quantile(apPurc_chg08, 0.1, na.rm = T),
    q25 = quantile(apPurc_chg08, 0.25, na.rm = T),
    med = median(apPurc_chg08, na.rm = T),
    q75 = quantile(apPurc_chg08, 0.75, na.rm = T),
    q90 = quantile(apPurc_chg08, 0.9, na.rm = T),
    mean = mean(apPurc_chg08, na.rm = T),
    sd = sd(apPurc_chg08, na.rm = T)
  )
apPurc_sum[2:ncol(apPurc_sum)] <- apply(
  apPurc_sum[2:ncol(apPurc_sum)],
  2, function(x) round(x, digits = 2)
)
write.xlsx(apPurc_sum, "../tables/table-b1_2.xlsx")

# Panel C: House purchase prices
houPurc_sum <- panel_krs %>%
  select(houPurc_chg08, year) %>%
  group_by(year) %>%
  summarise(
    q10 = quantile(houPurc_chg08, 0.1, na.rm = T),
    q25 = quantile(houPurc_chg08, 0.25, na.rm = T),
    med = median(houPurc_chg08, na.rm = T),
    q75 = quantile(houPurc_chg08, 0.75, na.rm = T),
    q90 = quantile(houPurc_chg08, 0.9, na.rm = T),
    mean = mean(houPurc_chg08, na.rm = T),
    sd = sd(houPurc_chg08, na.rm = T)
  )
houPurc_sum[2:ncol(houPurc_sum)] <- apply(
  houPurc_sum[2:ncol(houPurc_sum)],
  2, function(x) round(x, digits = 2)
)
write.xlsx(houPurc_sum, "../tables/table-b1_3.xlsx")
